[CalendarServer-changes] [13344] CalendarServer/trunk/txdav/who/test/test_group_attendees.py

source_changes at macosforge.org source_changes at macosforge.org
Mon Apr 21 09:18:28 PDT 2014


Revision: 13344
          http://trac.calendarserver.org//changeset/13344
Author:   cdaboo at apple.com
Date:     2014-04-21 09:18:28 -0700 (Mon, 21 Apr 2014)
Log Message:
-----------
Fix one aspect of a test (still broken). Add a new (unimplemented/failing) test.

Modified Paths:
--------------
    CalendarServer/trunk/txdav/who/test/test_group_attendees.py

Modified: CalendarServer/trunk/txdav/who/test/test_group_attendees.py
===================================================================
--- CalendarServer/trunk/txdav/who/test/test_group_attendees.py	2014-04-21 15:22:13 UTC (rev 13343)
+++ CalendarServer/trunk/txdav/who/test/test_group_attendees.py	2014-04-21 16:18:28 UTC (rev 13344)
@@ -527,10 +527,11 @@
 
 
     @inlineCallbacks
-    def test_groupRemoval(self):
+    def test_groupRemovalFromDirectory(self):
         """
         Test that removing a group also removes the expanded attendees. This needs to make sure
         that an attendee in two groups is NOT removed if only one of those groups is removed
         """
 
         yield self._verifyObjectResourceCount("10000000-0000-0000-0000-000000000006", 0)
@@ -599,6 +600,7 @@
 ATTENDEE;CN=User 09;EMAIL=user09 at example.com;MEMBER="urn:x-uid:20000000-0000-0000-0000-000000000003";PARTSTAT=NEEDS-ACTION;RSVP=TRUE;SCHEDULE-STATUS=1.2:urn:x-uid:10000000-0000-0000-0000-000000000009
 CREATED:20060101T150000Z
 ORGANIZER;CN=User 01;EMAIL=user01 at example.com:urn:x-uid:10000000-0000-0000-0000-000000000001
+SEQUENCE:1
 SUMMARY:event 1
 END:VEVENT
 END:VCALENDAR
@@ -656,6 +658,7 @@
         self.assertEqual(len(cobjs), 1)
         comp1 = yield cobjs[0].componentForUser()
         self.assertTrue("STATUS:CANCELLED" in str(comp1))
+        yield self.commit()
 
         # add group back, run cacher
         self.patch(DirectoryService, "recordWithUID", unpatchedRecordWithUID)
@@ -669,3 +672,13 @@
         cobj1 = yield self.calendarObjectUnderTest(name="data1.ics", calendar_name="calendar", home="10000000-0000-0000-0000-000000000001")
         vcalendar5 = yield cobj1.component()
         self._assertICalStrEqual(vcalendar5, data_get_1)
+
+
+    @inlineCallbacks
+    def test_groupRemovalFromEvent(self):
+        """
+        Test that removing a group from the calendar data also removes the expanded attendees.
+        This needs to make sure that an attendee in two groups is NOT removed if only one of
+        those groups is removed
+        """
+        self.fail("FIXME: need to implement this test")
-------------- next part --------------
@@ -527,10 +527,11 @@
         """
-        Test that removing a group also removes the expanded attendees. This needs to make sure
-        that an attendee in two groups is NOT removed if only one of those groups is removed
+        Test that removing a group from the directory also removes the expanded attendees.
+        This needs to make sure that an attendee in two groups is NOT removed if only one
+        of those groups is removed
         """
 
An HTML attachment was scrubbed...
URL: <https://lists.macosforge.org/pipermail/calendarserver-changes/attachments/20140421/09d2a78c/attachment-0001.html>


More information about the calendarserver-changes mailing list